@@ -13,10 +13,10 @@
  */
 
 import { commands, KeyMap, normalizeKeyMap } from 'codemirror'
-const clipboard = (window as any).clipboard
+const clipboard = window.clipboard
 
 export default function (): KeyMap {
-  let homeEndBehaviour = Boolean(global.config.get('editor.homeEndBehaviour'))
+  let homeEndBehaviour = Boolean(window.config.get('editor.homeEndBehaviour'))
   const keymap: KeyMap = {}
 
   // Crossplatform shortcuts
