@@ -20,8 +20,7 @@ import isFile from './is-file'
  * @param  {Boolean} skipExistenceCheck Whether or not to skip the existence check
  * @return {Boolean}   Returns true, if the path is an attachment, or false.
  */
-export default function isAttachment (p: string, skipExistenceCheck: boolean = false): boolean {
-  let ext = global.config.get('attachmentExtensions')
+export default function isAttachment (p: string, ext: string[], skipExistenceCheck: boolean = false): boolean {
   let fileExists = skipExistenceCheck ? true : isFile(p)
   return fileExists && ext.includes(extname(p).toLowerCase())
 }
