@@ -59,6 +59,11 @@ export default function (): any {
           label: trans('dialog.preferences.indent_unit'),
           model: 'editor.indentUnit'
         },
+        {
+          type: 'checkbox',
+          label: trans('dialog.preferences.indent_with_tabs'),
+          model: 'editor.indentWithTabs'
+        },
         {
           type: 'number',
           label: trans('dialog.preferences.editor_font_size'),
